@@ -192,7 +192,7 @@ def is_model_view_subclass_method_shouldnt_be_function(node):
 
     #subclass = 'django.views.generic.base.View'
     subclass = '.View'
-    return parent.name.endswith('View') and node_is_subclass(parent, subclass)
+    return parent is not None and parent.name.endswith('View') and node_is_subclass(parent, subclass)
 
 
 def is_model_view_subclass_unused_argument(node):
@@ -330,4 +330,4 @@ def apply_augmentations(linter):
     suppress_message(linter, MisdesignChecker.leave_class, 'R0903', is_model_mpttmeta_subclass)
 
     # ForeignKey and OneToOneField
-    VariablesChecker.leave_module = wrap(VariablesChecker.leave_module, ignore_import_warnings_for_related_fields)
\ No newline at end of file
+    VariablesChecker.leave_module = wrap(VariablesChecker.leave_module, ignore_import_warnings_for_related_fields)
